## 📖 About
# * **🤔💭What is CoreCompany?**
* here we will store all the company's software and files by category and name
* 

## 📚 CoreCompany Structure
```


📁 CoreCompany/ 
│ ├── 📁 OpenSourceSoftware/
│ │ ├── 📁 Signup and Login/
│ │ ├── 📁 Splash Screen/
│ │ ├── 📁 SystemMonitor/

│ ├── 📁 Saas/
│ │ ├── 📁 Media Cuts/